GOOF----LE-8-2.08       ] a 4     hi	      ] g  guile	 	g  process-use-modules	 	 	g  gnucash	g  gettext	 		 	
f  Arial	f  20	f   	
g  
string-length	g  string-index-right	g  	substring	g  string-take	g  string-contains-ci	f   bold	f  bold	g  
string-append	g  string-drop	f   italic	f  italic	f   oblique	f  oblique	f  
font-family: 	f  ; 	f  font-size: 	f  pt; 	f  font-style: 	f  
font-weight: 	 g  font-name-to-style-info	!g  "gnc-get-default-report-font-family	"g  gnc:make-font-option	#f  Fonts	$f  Title	%f  a	&f  Font info for the report title.	'f   Bold 15	(g  gnc:register-option	)f  Account link	*f  b	+f  Font info for account name.	,f  
 Italic 10	-f  Number cell	.f  c	/f  #Font info for regular number cells.	0f   10	1g  gnc:make-simple-boolean-option	2f  Negative Values in Red	3f  d	4f  Display negative values in red.	5f  
Number header	6f  e	7f  Font info for number headers.	8f  	Text cell	9f  f	:f  !Font info for regular text cells.	;f  Total number cell	<f  g	=f  .Font info for number cells containing a total.	>f   Bold 12	?f  Total label cell	@f  h	Af  ,Font info for cells containing total labels.	Bf  Centered label cell	Cf  i	Df  #Font info for centered label cells.	Eg  register-font-options	Fg  gnc:option-value	Gg  gnc:lookup-option	Hg  gnc:color-option->html	If  Colors	Jf  Alternate Table Cell Color	Kg  !gnc:html-document-set-style-text!	Lf  h3 { 	Mf   }
	Nf  a { 	Of  @body, p, table, tr, td { text-align: left; vertical-align: top; 	Pf  tr.alternate-row { background: 	Qf  +tr { page-break-inside: avoid !important;}
	Rf  +th.column-heading-left { text-align: left; 	Sf  /th.column-heading-center { text-align: center; 	Tf  -th.column-heading-right { text-align: right; 	Uf  	td.neg { 	Vf  color: red; 	Wf  Qtd.number-cell, td.total-number-cell { text-align: right; white-space: nowrap; }
	Xf  &td.date-cell { white-space: nowrap; }
	Yf  &td.anchor-cell { white-space: nowrap; 	Zf  td.number-cell { 	[f  &td.number-header { text-align: right; 	\f  td.text-cell { 	]f  td.total-number-cell { 	^f  td.total-label-cell { 	_f  -td.centered-label-cell { text-align: center; 	`g  add-css-information-to-docC 5  h     ] 4	 >  "  G  

 h8  Q  ]I H HHH
HH
HH4J 5
H	4J  5K	4J J	5K4J J	5K 4J 	5KJ$  $
K44J J54J J	55K "   4J 
5KJ$  $K44J J54J J	55K "  54J 5KJ$  $K44J J54J J	55K "   J K4JJJ$  4J5"  J$  4J5"  5KJC   I      g  	font-name
	5 g  font-family	5 g  	font-size		5 g  
font-style		5 g  font-style-idx		5 g  font-weight		5 g  font-weight-idx		5 g  result		5 g  len		%5 g  idx			(5  
g  filenamef  i/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/report-system/html-fonts.scm
	
		!						"						'						(		%			+	+		5	+		6	,		=	,	-	A	,		C	,		D	-		N	-		O	.		U	.	<	W	.		Y	.		_	/		a	1	&	c	1		d	2	(	g	2	7	p	3	7	y	3	N	{	3	7	}	2	(		2	 	5	 	5	; 	5	 	5	 	6	 	8	% 	8	 	9	( 	9	7 	:	7 	:	N 	:	7 	9	( 	9	 	=	- 	=	K 	=	- 	=	 	>	 	@	9 	@	( 	A	8 	A	G 	B	c 	B	z 	B	c 	A	8 	A	( 	D	 	E	 	F	 	F	, 	G	 	G	(	H		H		H	.	H	H	H		H	N	I		I	 "	I	/&	I	K(	I	 .	I	Q0	E	2	E	 P	5  g  nameg  font-name-to-style-info C R!"#$%&'()*+,-./0123456789:;<=>?@ABCD &     h    ]45 44554	 >  "  G  4
4
554	 >  "  G  44554	 >  "  G  454	 >  "  G  44554	 >  "  G  44554	 >  "  G  44554	 >  "  G  4 !"4554	 >  "  G  4#$%455	 6             g  options
	 g  font-family	 g  opt			8 g  opt		N	g g  opt		}  g  opt	   g  opt	   g  opt	 g  opt	1J g  opt	`y g  opt	  g  filenamef  i/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/report-system/html-fonts.scm
	N
		S			O		
	V			W			X			X			X	%		Y			Y	+		Y			V			U		"	R		9	[		=	\		?	]		A	]	$	C	]	,	D	^		J	^	+	L	^		N	[		N	Z		Q	R		h	`		l	a		n	b		p	b	#	r	b	+	s	c		y	c	+	{	c		}	`		}	_	 	R	 	e	 	f	 	g	 	g	. 	g	6 	e	 	d	 	R	 	j	 	k	 	l	 	l	% 	l	- 	m	 	m	+ 	m	 	j	 	i	 	R	 	o	 	p	 	q	 	q	! 	q	) 	r	 	r	+ 	r		o		n		R		t	 	u	"	v	$	v	)&	v	1'	w	-	w	+/	w	1	t	1	s	4	R	K	y	O	z	Q	{	S	{	(U	{	0V	|	\	|	+^	|	`	y	`	x	c	R	z	~	~		 	 	+ 	3 	 	+ 		~		}		R	 d	  g  nameg  register-font-options CERFG#2HIJ $)-58;?BKLMNOPQRSTUVWXYZ[\]^_ (hX    ]R44 5544 55444 	555444 
555444 555444 555444 
555444 555	444 555
444 5554$  "   !"#$%	&
'506   
      g  options
	U g  ssdoc	U g  
negative-red?		U g  alternate-row-color		$U g  title-font-info		;U g  account-link-font-info		RU g  number-cell-font-info		iU g  number-header-font-info	 U g  text-cell-font-info	 U g  total-number-cell-font-info		 U g  total-label-cell-font-info	
 U g  centered-label-cell-font-info	 U  g  filenamef  i/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/report-system/html-fonts.scm
 
	 		 	"	 	 	 	(	 	"	 		 		 			 	
	 		  		" 	
	$ 			$ 		' 		* 		- 	"	3 	;	5 	C	7 	"	9 		; 		; 		> 	 	A 		D 	"	J 	B	L 	J	N 	"	P 		R 	 	R 		U 		X 		[ 	"	a 	A	c 	I	e 	"	g 		i 		i 		l 	!	o 		r 	"	x 	C	z 	K	| 	"	~ 	  	!  	  	  	  	"  	?  	G  	"  	  	  	  	%  	  	"  	G  	O  	"  	  	%  	  	$  	  	"  	F  	N  	"  	  	$  	  	'  	  	"  	I  	Q  	"  	  	'  	  	  	  	(  	  	.  	  	g  	  	F  	 	 	V 	 	Z
 	 	X 	 	 	.! 	=# 	A% 	' 	) 	- 	M/ 	3 	:5 	9 	Q; 	? 	6A 	E 	FG 	K 	DM 	Q 	^S 	U 	 	U	  g  nameg  add-css-information-to-doc C`RC        g  filenamef  i/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/report-system/html-fonts.scm		
	
	N
 
 	
   C6 